==> 0.2.1.tar.gz: lib/utils/customcard.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
void screenUtilInit(BuildContext context) {
  ScreenUtil.init(
      BoxConstraints(
          maxWidth: MediaQuery.of(context).size.width,
          maxHeight: MediaQuery.of(context).size.height),
      designSize: const Size(375, 812));
}
// ignore: must_be_immutable
class appCard extends StatelessWidget {
  Widget child;
  EdgeInsetsGeometry? margin;
  EdgeInsetsGeometry? padding;
  Function? onTap;
  Color? color;
  double borderRadius = 12.0;
  appCard({required this.child, this.margin, this.padding, this.onTap, this.color});


  @override
  Widget build(BuildContext context) {
    screenUtilInit(context);
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(borderRadius),

      ),
      margin: margin ??=
          EdgeInsets.only(left: 8, right: 8.0, top: 6.0, bottom: 6.0),
      padding: EdgeInsets.all(0),
      child: Card(
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(borderRadius)),
        margin: EdgeInsets.all(0),
        color: color,
        elevation: 0,
        child: InkWell(
          onTap: onTap as void Function()?,
          child: Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(borderRadius),
            ),
            padding: padding ??=
                EdgeInsets.only(top: 8, bottom: 8, left: 16, right: 16),
            child: child,
          ),
        ),
      ),
    );
  }
}

// ignore: must_be_immutable
class appListCard extends StatelessWidget {
  Widget child;
  EdgeInsetsGeometry? margin;
  EdgeInsetsGeometry? padding;
  Function? onTap;
  Color? color;
  double borderRadius = 12.0;
  Clip? clip;
  appListCard(
      {required this.child,
      this.margin,
      this.padding,
      this.onTap,
      this.color,
      this.clip});

  @override
  Widget build(BuildContext context) {
    screenUtilInit(context);
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(borderRadius),

      ),
      margin: margin ??= EdgeInsets.only(left: 8, right: 8, top: 4, bottom: 4),
      padding: EdgeInsets.all(0),
      child: Card(
        clipBehavior: clip,
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(borderRadius)),
        margin: EdgeInsets.all(0),
        color: color,
        elevation: 0,
        child: InkWell(
          onTap: onTap as void Function()?,
          child: Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(borderRadius),
            ),
            padding: padding ??=
                EdgeInsets.only(top: 8, bottom: 4, left: 8, right: 8),
            child: ClipRRect(
                borderRadius: BorderRadius.circular(borderRadius),
                child: child),
          ),
        ),
      ),
    );
  }
}

==> 0.11.1.tar.gz: lib/utils/customcard.dart <==
import 'package:flutter/material.dart';

void screenUtilInit(BuildContext context) {}

// ignore: must_be_immutable
class appCard extends StatelessWidget {
  Widget child;
  EdgeInsetsGeometry? margin;
  EdgeInsetsGeometry? padding;
  Function? onTap;
  Color? color;
  double borderRadius = 12.0;

  appCard(
      {required this.child, this.margin, this.padding, this.onTap, this.color});

  @override
  Widget build(BuildContext context) {
    screenUtilInit(context);
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(borderRadius),
      ),
      margin: margin ??=
          EdgeInsets.only(left: 8, right: 8.0, top: 6.0, bottom: 6.0),
      padding: EdgeInsets.all(0),
      child: Card(
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(borderRadius)),
        margin: EdgeInsets.all(0),
        color: color,
        elevation: 0,
        child: InkWell(
          onTap: onTap as void Function()?,
          child: Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(borderRadius),
            ),
            padding: padding ??=
                EdgeInsets.only(top: 8, bottom: 8, left: 16, right: 16),
            child: child,
          ),
        ),
      ),
    );
  }
}

// ignore: must_be_immutable
class appListCard extends StatelessWidget {
  Widget child;
  EdgeInsetsGeometry? margin;
  EdgeInsetsGeometry? padding;
  Function? onTap;
  Color? color;
  double borderRadius = 12.0;
  Clip? clip;

  appListCard(
      {required this.child,
      this.margin,
      this.padding,
      this.onTap,
      this.color,
      this.clip});

  @override
  Widget build(BuildContext context) {
    screenUtilInit(context);
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(borderRadius),
      ),
      margin: margin ??= EdgeInsets.only(left: 8, right: 8, top: 4, bottom: 4),
      padding: EdgeInsets.all(0),
      child: Card(
        clipBehavior: clip,
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(borderRadius)),
        margin: EdgeInsets.all(0),
        color: color,
        elevation: 0,
        child: InkWell(
          onTap: onTap as void Function()?,
          child: Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(borderRadius),
            ),
            padding: padding ??=
                EdgeInsets.only(top: 8, bottom: 4, left: 8, right: 8),
            child: ClipRRect(
                borderRadius: BorderRadius.circular(borderRadius),
                child: child),
          ),
        ),
      ),
    );
  }
}
